@@ -3,8 +3,11 @@ package WWW::ProxyChecker;
 use warnings;
 use strict;
 
-our $VERSION = '1.001001'; # VERSION
+# VERSION
 
+our $VERSION = '1.004';
+
+use Data::Dumper;
 use Carp;
 use LWP::UserAgent;
 use IO::Pipe;
@@ -330,39 +333,33 @@ See C<CONSTRUCTOR> section for more information about these.
 
 =head1 REPOSITORY
 
-=for html  <div style="display: table; height: 91px; background: url(http://zoffix.com/CPAN/Dist-Zilla-Plugin-Pod-Spiffy/icons/section-github.png) no-repeat left; padding-left: 120px;" ><div style="display: table-cell; vertical-align: middle;">
-
-Fork this module on GitHub:
-L<https://github.com/zoffixznet/WWW-ProxyChecker>
-
-=for html  </div></div>
+L<https://github.com/stevieb9/p5-www-proxychecker>
 
 =head1 BUGS
 
-=for html  <div style="display: table; height: 91px; background: url(http://zoffix.com/CPAN/Dist-Zilla-Plugin-Pod-Spiffy/icons/section-bugs.png) no-repeat left; padding-left: 120px;" ><div style="display: table-cell; vertical-align: middle;">
-
 To report bugs or request features, please use
-L<https://github.com/zoffixznet/WWW-ProxyChecker/issues>
-
-If you can't access GitHub, you can email your request
-to C<bug-WWW-ProxyChecker at rt.cpan.org>
-
-=for html  </div></div>
+L<https://github.com/stevieb9/p5-www-proxychecker/issues>
 
 =head1 AUTHOR
 
-=for html  <div style="display: table; height: 91px; background: url(http://zoffix.com/CPAN/Dist-Zilla-Plugin-Pod-Spiffy/icons/section-author.png) no-repeat left; padding-left: 120px;" ><div style="display: table-cell; vertical-align: middle;">
+Zoffix Znet, C<< <zoffix at cpan.org> >>
+(L<http://zoffix.com>, L<http://haslayout.net>)
 
-=for html   <span style="display: inline-block; text-align: center;"> <a href="http://metacpan.org/author/ZOFFIX"> <img src="http://www.gravatar.com/avatar/328e658ab6b08dfb5c106266a4a5d065?d=http%3A%2F%2Fwww.gravatar.com%2Favatar%2F627d83ef9879f31bdabf448e666a32d5" alt="ZOFFIX" style="display: block; margin: 0 3px 5px 0!important; border: 1px solid #666; border-radius: 3px; "> <span style="color: #333; font-weight: bold;">ZOFFIX</span> </a> </span>
+Adopted on Feb 4, 2016 and currently maintained by:
 
-=for text Zoffix Znet <zoffix at cpan.org>
+Steve Bertrand C<< <steveb at cpan.org> >>
 
-=for html  </div></div>
+=head1 COPYRIGHT & LICENSE
 
-=head1 LICENSE
+Copyright 2016 Steve Bertrand
 
-You can use and distribute this module under the same terms as Perl itself.
-See the C<LICENSE> file included in this distribution for complete
-details.
+Copyright 2008 Zoffix Znet, all rights reserved.
 
-=cut
\ No newline at end of file
+This program is free software; you can redistribute it and/or modify it
+under the terms of either: the GNU General Public License as published
+by the Free Software Foundation; or the Artistic License.
+
+See L<http://dev.perl.org/licenses/> for more information.
+
+
+=cut
